@@ -75,6 +75,8 @@
 #define SHOW_SCREEN_KEY	"/apps/fast-user-switch-applet/show_screen_item"
 #define ACTIVE_ONLY_KEY	"/apps/fast-user-switch-applet/show_active_users_only"
 
+#define LOCKDOWN_DIR    "/desktop/gnome/lockdown"
+#define LOCKDOWN_KEY    LOCKDOWN_DIR "/disable_user_switching"
 
 /* ******************** *
  *  Private Structures  *
@@ -99,6 +101,7 @@ typedef struct _FusaAppletData
 
   guint client_notify_applet_id;
   guint client_notify_global_id;
+  guint client_notify_lockdown_id;
   guint user_notify_id;
   GQuark user_menu_item_quark;
   gint8 pixel_size;
@@ -185,6 +188,10 @@ static void client_notify_global_func (GConfClient *client,
 				       guint        cnxn_id,
 				       GConfEntry  *entry,
 				       gpointer     data);
+static void client_notify_lockdown_func (GConfClient *client,
+                                       guint        cnxn_id,
+                                       GConfEntry  *entry,
+                                       gpointer     data);
 
 /* Child Widget Callbacks */
 static void     prefs_radio_toggled_cb        (GtkToggleButton *button,
@@ -598,10 +605,21 @@ applet_fill_cb (PanelApplet *applet,
     gconf_client_notify_add (adata->client, GLOBAL_DIR,
 			     client_notify_global_func, adata, NULL, NULL);
 
+  adata->client_notify_lockdown_id =
+    gconf_client_notify_add (adata->client, LOCKDOWN_KEY,
+                             client_notify_lockdown_func, adata, NULL, NULL);
+
   adata->items = g_slist_sort_with_data (adata->items,
 					 sort_menu_comparedatafunc, adata);
 
-  gtk_widget_show (GTK_WIDGET (applet));
+  if (gconf_client_get_bool (adata->client, LOCKDOWN_KEY, NULL))
+    {
+      gtk_widget_hide (GTK_WIDGET (applet));
+    }
+  else
+    {
+      gtk_widget_show (GTK_WIDGET (applet));
+    }
 
   return TRUE;
 }
@@ -1229,6 +1247,36 @@ manager_user_added_cb (FusaManager *manager,
   sort_menu (adata);
 }
 
+static void
+client_notify_lockdown_func (GConfClient *client,
+                             guint        cnxn_id,
+                             GConfEntry  *entry,
+                             gpointer     data)
+{
+  FusaAppletData *adata;
+  GConfValue *value;
+  const gchar *key;
+             
+  adata = data;
+  value = gconf_entry_get_value (entry);
+  key = gconf_entry_get_key (entry);
+             
+  if (!value || !key)
+    return;
+             
+  if (strcmp (key, LOCKDOWN_KEY) == 0)
+    {
+      if (gconf_value_get_bool (value))
+        {
+          gtk_widget_hide ( GTK_WIDGET (adata->applet));
+        }
+      else
+        {
+          gtk_widget_show ( GTK_WIDGET (adata->applet));
+        }
+    }
+}            
+
 static void
 user_displays_changed_cb (FusaUser *user,
 			  gpointer  data)
